Package: igraph
Title: Network Analysis and Visualization
Version: 2.1.4
Authors@R: c(
    person("Gábor", "Csárdi", , "csardi.gabor@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-7098-9676")),
    person("Tamás", "Nepusz", , "ntamas@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-1451-338X")),
    person("Vincent", "Traag", role = "aut",
           comment = c(ORCID = "0000-0003-3170-3879")),
    person("Szabolcs", "Horvát", , "szhorvat@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-3100-523X")),
    person("Fabio", "Zanini", , "fabio.zanini@unsw.edu.au", role = "aut",
           comment = c(ORCID = "0000-0001-7097-8539")),
    person("Daniel", "Noom", role = "aut"),
    person("Kirill", "Müller", , "kirill@cynkra.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-1416-3412")),
    person("Maëlle", "Salmon", role = "ctb"),
    person("Michael", "Antonov", role = "ctb"),
    person("Chan Zuckerberg Initiative", role = "fnd")
  )
Description: Routines for simple graphs and network analysis. It can
    handle large graphs very well and provides functions for generating
    random and regular graphs, graph visualization, centrality methods and
    much more.
License: GPL (>= 2)
URL: https://r.igraph.org/, https://igraph.org/,
        https://igraph.discourse.group/
BugReports: https://github.com/igraph/rigraph/issues
Depends: methods, R (>= 3.5.0)
Imports: cli, graphics, grDevices, lifecycle, magrittr, Matrix,
        pkgconfig (>= 2.0.0), rlang, stats, utils, vctrs
Suggests: ape (>= 5.7-0.1), callr, decor, digest, igraphdata, knitr,
        rgl (>= 1.3.14), rmarkdown, scales, stats4, tcltk, testthat,
        vdiffr, withr
Enhances: graph
LinkingTo: cpp11 (>= 0.5.0)
VignetteBuilder: knitr
Config/Needs/build: roxygen2, devtools, irlba, pkgconfig,
        igraph/igraph.r2cdocs, moodymudskipper/devtag
Config/Needs/coverage: covr
Config/Needs/website: readr
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/testthat/start-first: vs-es, scan, vs-operators, weakref,
        watts.strogatz.game
Encoding: UTF-8
RoxygenNote: 7.3.2.9000
SystemRequirements: libxml2 (optional), glpk (>= 4.57, optional)
NeedsCompilation: yes
Packaged: 2025-01-22 19:28:33 UTC; kirill
Author: Gábor Csárdi [aut] (<https://orcid.org/0000-0001-7098-9676>),
  Tamás Nepusz [aut] (<https://orcid.org/0000-0002-1451-338X>),
  Vincent Traag [aut] (<https://orcid.org/0000-0003-3170-3879>),
  Szabolcs Horvát [aut] (<https://orcid.org/0000-0002-3100-523X>),
  Fabio Zanini [aut] (<https://orcid.org/0000-0001-7097-8539>),
  Daniel Noom [aut],
  Kirill Müller [aut, cre] (<https://orcid.org/0000-0002-1416-3412>),
  Maëlle Salmon [ctb],
  Michael Antonov [ctb],
  Chan Zuckerberg Initiative [fnd]
Maintainer: Kirill Müller <kirill@cynkra.com>
Repository: CRAN
Date/Publication: 2025-01-23 10:20:02 UTC
Built: R 4.5.2; x86_64--netbsd; 2026-02-24 02:59:11 UTC; unix
