# Generated by roxygen2: do not edit by hand

S3method("$",igraph)
S3method("$",igraph.es)
S3method("$",igraph.vs)
S3method("$<-",igraph)
S3method("$<-",igraph.es)
S3method("$<-",igraph.vs)
S3method("*",igraph)
S3method("+",igraph)
S3method("-",igraph)
S3method("[",communities)
S3method("[",igraph)
S3method("[",igraph.es)
S3method("[",igraph.vs)
S3method("[<-",igraph)
S3method("[<-",igraph.es)
S3method("[<-",igraph.vs)
S3method("[[",communities)
S3method("[[",igraph)
S3method("[[",igraph.es)
S3method("[[",igraph.vs)
S3method("[[<-",igraph.es)
S3method("[[<-",igraph.vs)
S3method(as.dendrogram,communities)
S3method(as.hclust,communities)
S3method(as.hclust,igraphHRG)
S3method(as.igraph,igraphHRG)
S3method(as.matrix,igraph)
S3method(as_ids,igraph.es)
S3method(as_ids,igraph.vs)
S3method(c,igraph.es)
S3method(c,igraph.vs)
S3method(cohesion,cohesiveBlocks)
S3method(cohesion,igraph)
S3method(compare,communities)
S3method(compare,default)
S3method(compare,membership)
S3method(difference,igraph)
S3method(difference,igraph.es)
S3method(difference,igraph.vs)
S3method(graph_id,igraph)
S3method(graph_id,igraph.es)
S3method(graph_id,igraph.vs)
S3method(groups,communities)
S3method(groups,default)
S3method(intersection,igraph)
S3method(intersection,igraph.es)
S3method(intersection,igraph.vs)
S3method(length,cohesiveBlocks)
S3method(length,communities)
S3method(length,igraph)
S3method(median,sir)
S3method(modularity,communities)
S3method(modularity,igraph)
S3method(plot,cohesiveBlocks)
S3method(plot,communities)
S3method(plot,igraph)
S3method(plot,sir)
S3method(plot_dendrogram,communities)
S3method(plot_dendrogram,igraphHRG)
S3method(print,cohesiveBlocks)
S3method(print,communities)
S3method(print,igraph)
S3method(print,igraph.es)
S3method(print,igraph.vs)
S3method(print,igraphHRG)
S3method(print,igraphHRGConsensus)
S3method(print,igraph_layout_modifier)
S3method(print,igraph_layout_spec)
S3method(print,igraph_version)
S3method(print,membership)
S3method(quantile,sir)
S3method(rep,igraph)
S3method(rev,igraph.es)
S3method(rev,igraph.vs)
S3method(rglplot,igraph)
S3method(summary,cohesiveBlocks)
S3method(summary,igraph)
S3method(t,igraph)
S3method(time_bins,sir)
S3method(union,default)
S3method(union,igraph)
S3method(union,igraph.es)
S3method(union,igraph.vs)
S3method(unique,igraph.es)
S3method(unique,igraph.vs)
export("%--%")
export("%->%")
export("%<-%")
export("%>%")
export("%c%")
export("%du%")
export("%m%")
export("%s%")
export("%u%")
export("E<-")
export("V<-")
export("edge.attributes<-")
export("edge_attr<-")
export("graph.attributes<-")
export("graph_attr<-")
export("vertex.attributes<-")
export("vertex_attr<-")
export(.data)
export(.env)
export(.from)
export(.inc)
export(.innei)
export(.nei)
export(.outnei)
export(.to)
export(E)
export(V)
export(add.edges)
export(add.vertex.shape)
export(add.vertices)
export(add_edges)
export(add_layout_)
export(add_shape)
export(add_vertices)
export(adhesion)
export(adjacent.triangles)
export(adjacent_vertices)
export(aging.ba.game)
export(aging.barabasi.game)
export(aging.prefatt.game)
export(algorithm)
export(align_layout)
export(all_shortest_paths)
export(all_simple_paths)
export(alpha.centrality)
export(alpha_centrality)
export(any_loop)
export(any_multiple)
export(are.connected)
export(are_adjacent)
export(arpack)
export(arpack_defaults)
export(articulation.points)
export(articulation_points)
export(as.directed)
export(as.igraph)
export(as.undirected)
export(as_adj)
export(as_adj_edge_list)
export(as_adj_list)
export(as_adjacency_matrix)
export(as_biadjacency_matrix)
export(as_bipartite)
export(as_data_frame)
export(as_directed)
export(as_edgelist)
export(as_graphnel)
export(as_ids)
export(as_incidence_matrix)
export(as_long_data_frame)
export(as_membership)
export(as_phylo)
export(as_star)
export(as_tree)
export(as_undirected)
export(assortativity)
export(assortativity.degree)
export(assortativity.nominal)
export(assortativity_degree)
export(assortativity_nominal)
export(asym_pref)
export(asymmetric.preference.game)
export(atlas)
export(authority.score)
export(authority_score)
export(autocurve.edges)
export(automorphism_group)
export(automorphisms)
export(average.path.length)
export(average_local_efficiency)
export(ba.game)
export(barabasi.game)
export(betweenness)
export(betweenness.estimate)
export(bfs)
export(bibcoupling)
export(biconnected.components)
export(biconnected_components)
export(bipartite)
export(bipartite.mapping)
export(bipartite.projection)
export(bipartite.projection.size)
export(bipartite.random.game)
export(bipartite_gnm)
export(bipartite_gnp)
export(bipartite_graph)
export(bipartite_mapping)
export(bipartite_projection)
export(bipartite_projection_size)
export(blockGraphs)
export(blocks)
export(bonpow)
export(bridges)
export(callaway.traits.game)
export(canonical.permutation)
export(canonical_permutation)
export(categorical_pal)
export(centr_betw)
export(centr_betw_tmax)
export(centr_clo)
export(centr_clo_tmax)
export(centr_degree)
export(centr_degree_tmax)
export(centr_eigen)
export(centr_eigen_tmax)
export(centralization.betweenness)
export(centralization.betweenness.tmax)
export(centralization.closeness)
export(centralization.closeness.tmax)
export(centralization.degree)
export(centralization.degree.tmax)
export(centralization.evcent)
export(centralization.evcent.tmax)
export(centralize)
export(centralize.scores)
export(chordal_ring)
export(chung_lu)
export(circulant)
export(cit_cit_types)
export(cit_types)
export(cited.type.game)
export(citing.cited.type.game)
export(clique.number)
export(clique_num)
export(clique_size_counts)
export(cliques)
export(closeness)
export(closeness.estimate)
export(cluster.distribution)
export(cluster_edge_betweenness)
export(cluster_fast_greedy)
export(cluster_fluid_communities)
export(cluster_infomap)
export(cluster_label_prop)
export(cluster_leading_eigen)
export(cluster_leiden)
export(cluster_louvain)
export(cluster_optimal)
export(cluster_spinglass)
export(cluster_walktrap)
export(clusters)
export(cocitation)
export(code.length)
export(code_len)
export(cohesion)
export(cohesive.blocks)
export(cohesive_blocks)
export(communities)
export(compare)
export(complementer)
export(component_distribution)
export(component_wise)
export(components)
export(compose)
export(connect)
export(connect.neighborhood)
export(consensus_tree)
export(console)
export(constraint)
export(contract)
export(contract.vertices)
export(convex.hull)
export(convex_hull)
export(coreness)
export(count.multiple)
export(count_automorphisms)
export(count_components)
export(count_isomorphisms)
export(count_loops)
export(count_max_cliques)
export(count_motifs)
export(count_multiple)
export(count_reachable)
export(count_subgraph_isomorphisms)
export(count_triangles)
export(create.communities)
export(crossing)
export(curve_multiple)
export(cut_at)
export(cutat)
export(de_bruijn_graph)
export(decompose)
export(decompose.graph)
export(degree)
export(degree.distribution)
export(degree.sequence.game)
export(degree_distribution)
export(degseq)
export(delete.edges)
export(delete.vertices)
export(delete_edge_attr)
export(delete_edges)
export(delete_graph_attr)
export(delete_vertex_attr)
export(delete_vertices)
export(dendPlot)
export(dfs)
export(diameter)
export(difference)
export(dim_select)
export(directed_graph)
export(disjoint_union)
export(distance_table)
export(distances)
export(diverging_pal)
export(diversity)
export(dominator.tree)
export(dominator_tree)
export(dot_product)
export(drl_defaults)
export(dyad.census)
export(dyad_census)
export(each_edge)
export(eccentricity)
export(ecount)
export(edge)
export(edge.attributes)
export(edge.betweenness)
export(edge.betweenness.community)
export(edge.betweenness.estimate)
export(edge.connectivity)
export(edge.disjoint.paths)
export(edge_attr)
export(edge_attr_names)
export(edge_betweenness)
export(edge_connectivity)
export(edge_density)
export(edge_disjoint_paths)
export(edges)
export(ego)
export(ego_size)
export(eigen_centrality)
export(embed_adjacency_matrix)
export(embed_laplacian_matrix)
export(empty_graph)
export(ends)
export(erdos.renyi.game)
export(establishment.game)
export(estimate_betweenness)
export(estimate_closeness)
export(estimate_edge_betweenness)
export(eulerian_cycle)
export(eulerian_path)
export(evcent)
export(exportPajek)
export(export_pajek)
export(farthest.nodes)
export(farthest_vertices)
export(fastgreedy.community)
export(feedback_arc_set)
export(feedback_vertex_set)
export(find_cycle)
export(fit_hrg)
export(fit_power_law)
export(forest.fire.game)
export(from_adjacency)
export(from_data_frame)
export(from_edgelist)
export(from_incidence_matrix)
export(from_literal)
export(from_prufer)
export(full_bipartite_graph)
export(full_citation_graph)
export(full_graph)
export(full_multipartite)
export(get.adjacency)
export(get.adjedgelist)
export(get.adjlist)
export(get.all.shortest.paths)
export(get.data.frame)
export(get.diameter)
export(get.edge)
export(get.edge.attribute)
export(get.edge.ids)
export(get.edgelist)
export(get.edges)
export(get.graph.attribute)
export(get.incidence)
export(get.shortest.paths)
export(get.stochastic)
export(get.vertex.attribute)
export(getIgraphOpt)
export(get_diameter)
export(get_edge_ids)
export(girth)
export(global_efficiency)
export(gnm)
export(gnp)
export(gorder)
export(graph)
export(graph.adhesion)
export(graph.adjacency)
export(graph.adjlist)
export(graph.atlas)
export(graph.attributes)
export(graph.automorphisms)
export(graph.bfs)
export(graph.bipartite)
export(graph.cohesion)
export(graph.complementer)
export(graph.compose)
export(graph.coreness)
export(graph.count.isomorphisms.vf2)
export(graph.count.subisomorphisms.vf2)
export(graph.data.frame)
export(graph.de.bruijn)
export(graph.density)
export(graph.dfs)
export(graph.difference)
export(graph.disjoint.union)
export(graph.diversity)
export(graph.edgelist)
export(graph.eigen)
export(graph.empty)
export(graph.extended.chordal.ring)
export(graph.famous)
export(graph.formula)
export(graph.full)
export(graph.full.bipartite)
export(graph.full.citation)
export(graph.get.isomorphisms.vf2)
export(graph.get.subisomorphisms.vf2)
export(graph.graphdb)
export(graph.incidence)
export(graph.intersection)
export(graph.isoclass)
export(graph.isoclass.subgraph)
export(graph.isocreate)
export(graph.isomorphic)
export(graph.isomorphic.bliss)
export(graph.isomorphic.vf2)
export(graph.kautz)
export(graph.knn)
export(graph.laplacian)
export(graph.lattice)
export(graph.lcf)
export(graph.maxflow)
export(graph.mincut)
export(graph.motifs)
export(graph.motifs.est)
export(graph.motifs.no)
export(graph.neighborhood)
export(graph.ring)
export(graph.star)
export(graph.strength)
export(graph.subisomorphic.lad)
export(graph.subisomorphic.vf2)
export(graph.tree)
export(graph.union)
export(graph_)
export(graph_attr)
export(graph_attr_names)
export(graph_center)
export(graph_from_adj_list)
export(graph_from_adjacency_matrix)
export(graph_from_atlas)
export(graph_from_biadjacency_matrix)
export(graph_from_data_frame)
export(graph_from_edgelist)
export(graph_from_graphdb)
export(graph_from_graphnel)
export(graph_from_incidence_matrix)
export(graph_from_isomorphism_class)
export(graph_from_lcf)
export(graph_from_literal)
export(graph_id)
export(graph_version)
export(graphlet_basis)
export(graphlet_proj)
export(graphlets)
export(graphlets.candidate.basis)
export(graphlets.project)
export(graphs_from_cohesive_blocks)
export(greedy_vertex_coloring)
export(grg)
export(grg.game)
export(groups)
export(growing)
export(growing.random.game)
export(gsize)
export(harmonic_centrality)
export(has.multiple)
export(has_eulerian_cycle)
export(has_eulerian_path)
export(head_of)
export(head_print)
export(hierarchical_sbm)
export(hierarchy)
export(hits_scores)
export(hrg)
export(hrg.consensus)
export(hrg.create)
export(hrg.dendrogram)
export(hrg.fit)
export(hrg.game)
export(hrg.predict)
export(hrg_tree)
export(hub.score)
export(hub_score)
export(identical_graphs)
export(igraph.console)
export(igraph.drl.coarsen)
export(igraph.drl.coarsest)
export(igraph.drl.default)
export(igraph.drl.final)
export(igraph.drl.refine)
export(igraph.from.graphNEL)
export(igraph.options)
export(igraph.sample)
export(igraph.shape.noclip)
export(igraph.shape.noplot)
export(igraph.to.graphNEL)
export(igraph.version)
export(igraph_opt)
export(igraph_options)
export(igraph_version)
export(in_circle)
export(incident)
export(incident_edges)
export(indent_print)
export(independence.number)
export(independence_number)
export(independent.vertex.sets)
export(induced.subgraph)
export(induced_subgraph)
export(infomap.community)
export(interconnected.islands.game)
export(intersection)
export(invalidate_cache)
export(is.bipartite)
export(is.chordal)
export(is.connected)
export(is.dag)
export(is.degree.sequence)
export(is.directed)
export(is.graphical.degree.sequence)
export(is.hierarchical)
export(is.igraph)
export(is.loop)
export(is.matching)
export(is.maximal.matching)
export(is.minimal.separator)
export(is.multiple)
export(is.mutual)
export(is.named)
export(is.separator)
export(is.simple)
export(is.weighted)
export(is_acyclic)
export(is_biconnected)
export(is_bipartite)
export(is_chordal)
export(is_clique)
export(is_complete)
export(is_connected)
export(is_dag)
export(is_degseq)
export(is_directed)
export(is_forest)
export(is_graphical)
export(is_hierarchical)
export(is_igraph)
export(is_isomorphic_to)
export(is_ivs)
export(is_matching)
export(is_max_matching)
export(is_min_separator)
export(is_named)
export(is_printer_callback)
export(is_separator)
export(is_simple)
export(is_subgraph_isomorphic_to)
export(is_tree)
export(is_weighted)
export(isomorphic)
export(isomorphism_class)
export(isomorphisms)
export(ivs)
export(ivs_size)
export(k.regular.game)
export(k_shortest_paths)
export(kautz_graph)
export(keeping_degseq)
export(knn)
export(label.propagation.community)
export(laplacian_matrix)
export(largest.cliques)
export(largest.independent.vertex.sets)
export(largest_cliques)
export(largest_component)
export(largest_ivs)
export(largest_weighted_cliques)
export(last_cit)
export(lastcit.game)
export(lattice)
export(layout.auto)
export(layout.bipartite)
export(layout.circle)
export(layout.davidson.harel)
export(layout.drl)
export(layout.fruchterman.reingold)
export(layout.fruchterman.reingold.grid)
export(layout.gem)
export(layout.graphopt)
export(layout.grid)
export(layout.grid.3d)
export(layout.kamada.kawai)
export(layout.lgl)
export(layout.mds)
export(layout.merge)
export(layout.norm)
export(layout.random)
export(layout.reingold.tilford)
export(layout.sphere)
export(layout.spring)
export(layout.star)
export(layout.sugiyama)
export(layout.svd)
export(layout_)
export(layout_as_bipartite)
export(layout_as_star)
export(layout_as_tree)
export(layout_components)
export(layout_in_circle)
export(layout_modifier)
export(layout_nicely)
export(layout_on_grid)
export(layout_on_sphere)
export(layout_randomly)
export(layout_with_dh)
export(layout_with_drl)
export(layout_with_fr)
export(layout_with_gem)
export(layout_with_graphopt)
export(layout_with_kk)
export(layout_with_lgl)
export(layout_with_mds)
export(layout_with_sugiyama)
export(leading.eigenvector.community)
export(line.graph)
export(line_graph)
export(list.edge.attributes)
export(list.graph.attributes)
export(list.vertex.attributes)
export(local_efficiency)
export(local_scan)
export(make_)
export(make_bipartite_graph)
export(make_chordal_ring)
export(make_circulant)
export(make_clusters)
export(make_de_bruijn_graph)
export(make_directed_graph)
export(make_ego_graph)
export(make_empty_graph)
export(make_from_prufer)
export(make_full_bipartite_graph)
export(make_full_citation_graph)
export(make_full_graph)
export(make_full_multipartite)
export(make_graph)
export(make_kautz_graph)
export(make_lattice)
export(make_line_graph)
export(make_neighborhood_graph)
export(make_ring)
export(make_star)
export(make_tree)
export(make_turan)
export(make_undirected_graph)
export(make_wheel)
export(match_vertices)
export(max_bipartite_match)
export(max_cardinality)
export(max_cliques)
export(max_cohesion)
export(max_degree)
export(max_flow)
export(max_ivs)
export(maxcohesion)
export(maximal.cliques)
export(maximal.cliques.count)
export(maximal.independent.vertex.sets)
export(maximal_ivs)
export(maximum.bipartite.matching)
export(maximum.cardinality.search)
export(mean_degree)
export(mean_distance)
export(membership)
export(merge_coords)
export(merges)
export(min_cut)
export(min_separators)
export(min_st_separators)
export(minimal.st.separators)
export(minimum.size.separators)
export(minimum.spanning.tree)
export(mod.matrix)
export(modularity)
export(modularity_matrix)
export(motifs)
export(mst)
export(multilevel.community)
export(neighborhood)
export(neighborhood.size)
export(neighborhood_size)
export(neighbors)
export(nicely)
export(no.clusters)
export(norm_coords)
export(normalize)
export(on_grid)
export(on_sphere)
export(optimal.community)
export(pa)
export(pa_age)
export(page.rank)
export(page_rank)
export(parent)
export(path)
export(path.length.hist)
export(permute)
export(permute.vertices)
export(piecewise.layout)
export(plot.igraph)
export(plotHierarchy)
export(plot_dendrogram)
export(plot_hierarchy)
export(power.law.fit)
export(power_centrality)
export(predict_edges)
export(pref)
export(preference.game)
export(print.igraph)
export(print_all)
export(printer_callback)
export(r_pal)
export(radius)
export(random.graph.game)
export(random_edge_walk)
export(random_walk)
export(randomly)
export(read.graph)
export(read_graph)
export(realize_bipartite_degseq)
export(realize_degseq)
export(reciprocity)
export(remove.edge.attribute)
export(remove.graph.attribute)
export(remove.vertex.attribute)
export(reverse_edges)
export(rewire)
export(rglplot)
export(ring)
export(running.mean)
export(running_mean)
export(sample_)
export(sample_asym_pref)
export(sample_bipartite)
export(sample_bipartite_gnm)
export(sample_bipartite_gnp)
export(sample_chung_lu)
export(sample_cit_cit_types)
export(sample_cit_types)
export(sample_correlated_gnp)
export(sample_correlated_gnp_pair)
export(sample_degseq)
export(sample_dirichlet)
export(sample_dot_product)
export(sample_fitness)
export(sample_fitness_pl)
export(sample_forestfire)
export(sample_gnm)
export(sample_gnp)
export(sample_grg)
export(sample_growing)
export(sample_hierarchical_sbm)
export(sample_hrg)
export(sample_islands)
export(sample_k_regular)
export(sample_last_cit)
export(sample_motifs)
export(sample_pa)
export(sample_pa_age)
export(sample_pref)
export(sample_sbm)
export(sample_seq)
export(sample_smallworld)
export(sample_spanning_tree)
export(sample_sphere_surface)
export(sample_sphere_volume)
export(sample_traits)
export(sample_traits_callaway)
export(sample_tree)
export(sbm)
export(sbm.game)
export(scan_stat)
export(sequential_pal)
export(set.edge.attribute)
export(set.graph.attribute)
export(set.vertex.attribute)
export(set_edge_attr)
export(set_graph_attr)
export(set_vertex_attr)
export(set_vertex_attrs)
export(shape_noclip)
export(shape_noplot)
export(shapes)
export(shortest.paths)
export(shortest_paths)
export(show_trace)
export(showtrace)
export(similarity)
export(similarity.dice)
export(similarity.invlogweighted)
export(similarity.jaccard)
export(simple_cycles)
export(simplified)
export(simplify)
export(simplify_and_colorize)
export(sir)
export(sizes)
export(smallworld)
export(spectrum)
export(spinglass.community)
export(split_join_distance)
export(stCuts)
export(stMincuts)
export(st_cuts)
export(st_min_cuts)
export(star)
export(static.fitness.game)
export(static.power.law.game)
export(stochastic_matrix)
export(strength)
export(subcomponent)
export(subgraph)
export(subgraph.centrality)
export(subgraph.edges)
export(subgraph_centrality)
export(subgraph_from_edges)
export(subgraph_isomorphic)
export(subgraph_isomorphisms)
export(tail_of)
export(time_bins)
export(tk_canvas)
export(tk_center)
export(tk_close)
export(tk_coords)
export(tk_fit)
export(tk_off)
export(tk_postscript)
export(tk_reshape)
export(tk_rotate)
export(tk_set_coords)
export(tkplot)
export(tkplot.canvas)
export(tkplot.center)
export(tkplot.close)
export(tkplot.export.postscript)
export(tkplot.fit.to.screen)
export(tkplot.getcoords)
export(tkplot.off)
export(tkplot.reshape)
export(tkplot.rotate)
export(tkplot.setcoords)
export(to_prufer)
export(topo_sort)
export(topological.sort)
export(traits)
export(traits_callaway)
export(transitive_closure)
export(transitivity)
export(tree)
export(triad.census)
export(triad_census)
export(triangles)
export(turan)
export(undirected_graph)
export(unfold.tree)
export(unfold_tree)
export(union)
export(upgrade_graph)
export(vcount)
export(vertex)
export(vertex.attributes)
export(vertex.connectivity)
export(vertex.disjoint.paths)
export(vertex.shapes)
export(vertex_attr)
export(vertex_attr_names)
export(vertex_connectivity)
export(vertex_disjoint_paths)
export(vertices)
export(voronoi_cells)
export(walktrap.community)
export(watts.strogatz.game)
export(weighted_clique_num)
export(weighted_cliques)
export(wheel)
export(which_loop)
export(which_multiple)
export(which_mutual)
export(with_dh)
export(with_drl)
export(with_edge_)
export(with_fr)
export(with_gem)
export(with_graph_)
export(with_graphopt)
export(with_igraph_opt)
export(with_kk)
export(with_lgl)
export(with_mds)
export(with_sugiyama)
export(with_vertex_)
export(without_attr)
export(without_loops)
export(without_multiples)
export(write.graph)
export(write_graph)
import(methods)
import(rlang)
importFrom(grDevices,as.raster)
importFrom(grDevices,col2rgb)
importFrom(grDevices,palette)
importFrom(grDevices,rainbow)
importFrom(graphics,hist)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,rasterImage)
importFrom(graphics,segments)
importFrom(graphics,symbols)
importFrom(graphics,text)
importFrom(graphics,xspline)
importFrom(graphics,xyinch)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(pkgconfig,get_config)
importFrom(pkgconfig,set_config)
importFrom(pkgconfig,set_config_in)
importFrom(rlang,caller_env)
importFrom(stats,IQR)
importFrom(stats,as.dendrogram)
importFrom(stats,as.hclust)
importFrom(stats,ave)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,rect.hclust)
importFrom(stats,reorder)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
useDynLib(igraph, .registration = TRUE)
