
# R/igraph

R/igraph is an R package of the igraph network analysis library.

## Installation

You can install the stable version of R/igraph from CRAN:

```r
install.packages("igraph")
```

For the development version, you can use Github, with the `devtools`
package:

```r
devtools::install_github("gaborcsardi/pkgconfig")
devtools::install_github("igraph/rigraph")
```

## Documentation

See the [igraph homepage](http://igraph.org/r) for the complete manual.

## Contributions

Please read our
[contribution guide](https://github.com/igraph/rigraph/blob/dev/CONTRIBUTING.md).

## License

GNU GPL version 2 or later
